mail Package
============

:mod:`smtpbootstrapper` Module
------------------------------

.. automodule:: leap.services.mail.smtpbootstrapper
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`smtpconfig` Module
------------------------

.. automodule:: leap.services.mail.smtpconfig
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`smtpspec` Module
----------------------

.. automodule:: leap.services.mail.smtpspec
    :members:
    :undoc-members:
    :show-inheritance:

